@@ -4,7 +4,7 @@ from scipy import signal
 from scipy.fftpack import fft
 
 
-def fourier(epochized_data: List[int or float], sampling_freq: int or float) -> List[np.ndarray]:
+def fourier(epochized_data: List[List[int or float]], sampling_freq: int or float) -> List[np.ndarray]:
 	"""
 
 	Args:
